@@ -21,23 +21,6 @@ class Puppet::Provider::Keystone < Puppet::Provider::Openstack
     @admin_token ||= get_admin_token
   end
 
-  def self.clean_host(host)
-    host ||= '127.0.0.1'
-    case host
-    when '0.0.0.0'
-      return '127.0.0.1'
-    when '::0'
-      return '[::1]'
-    else
-      # if ipv6, make sure ip address has brackets - LP#1541512
-      if host.include?(':') and !host.include?(']')
-        return "[" + host + "]"
-      else
-        return host
-      end
-    end
-  end
-
   def self.default_domain_from_ini_file
     default_domain_from_conf = Puppet::Resource.indirection
       .find('Keystone_config/identity/default_domain_id')
@@ -171,15 +154,8 @@ class Puppet::Provider::Keystone < Puppet::Provider::Openstack
 
   def self.get_public_endpoint
     endpoint = nil
-    if keystone_file
-      if url = get_section('DEFAULT', 'public_endpoint')
-        endpoint = url.chomp('/')
-      else
-        public_port = get_section('DEFAULT', 'public_port') || '5000'
-        host = clean_host(get_section('DEFAULT', 'public_bind_host'))
-        protocol = ssl? ? 'https' : 'http'
-        endpoint = "#{protocol}://#{host}:#{public_port}"
-      end
+    if url = get_section('DEFAULT', 'public_endpoint')
+      endpoint = url.chomp('/')
     end
     return endpoint
   end
@@ -208,7 +184,10 @@ class Puppet::Provider::Keystone < Puppet::Provider::Openstack
 
   def self.get_service_url
     service_url = nil
-    if ENV['OS_URL']
+    if ENV['OS_ENDPOINT']
+      service_url = ENV['OS_ENDPOINT'].dup
+    # Compatibility with pre-4.0.0 openstackclient
+    elsif ENV['OS_URL']
       service_url = ENV['OS_URL'].dup
     elsif public_endpoint
       service_url = public_endpoint
@@ -238,10 +217,16 @@ class Puppet::Provider::Keystone < Puppet::Provider::Openstack
 
   def self.request_by_service_token(service, action, error, properties=nil, options={})
     properties ||= []
-    @credentials.token = admin_token
-    @credentials.url   = service_url
+    @credentials.token    = admin_token
+    @credentials.endpoint = service_url
     raise error unless @credentials.service_token_set?
-    Puppet::Provider::Openstack.request(service, action, properties, @credentials, options)
+    begin
+      Puppet::Provider::Openstack.request(service, action, properties, @credentials, options)
+    rescue Puppet::ExecutionFailure, Puppet::Error::OpenstackUnauthorizedError
+      # openstackclient < 4.0.0 does not support --os-endpoint and requires --os-url
+      @credentials.url = service_url
+      Puppet::Provider::Openstack.request(service, action, properties, @credentials, options)
+    end
   end
 
   def self.service_url
@@ -263,13 +248,6 @@ class Puppet::Provider::Keystone < Puppet::Provider::Openstack
     end
   end
 
-  def self.ssl?
-    if keystone_file && keystone_file['ssl'] && keystone_file['ssl']['enable'] && keystone_file['ssl']['enable'].strip.downcase == 'true'
-      return true
-    end
-    return false
-  end
-
   # Helper functions to use on the pre-validated enabled field
   def bool_to_sym(bool)
     bool == true ? :true : :false
