@@ -83,10 +83,6 @@ describe 'keystone server running with Apache/WSGI as Identity Provider' do
       it { is_expected.to be_listening }
     end
 
-    describe port(35357) do
-      it { is_expected.to be_listening }
-    end
-
     describe cron do
       it { is_expected.to have_entry('1 * * * * keystone-manage token_flush >>/var/log/keystone/keystone-tokenflush.log 2>&1').with_user('keystone') }
     end
@@ -111,7 +107,7 @@ describe 'keystone server running with Apache/WSGI as Identity Provider' do
         end
       end
       it 'should find admin role' do
-        shell("openstack #{auth_creds} --os-auth-url http://127.0.0.1:5000/v3 --os-identity-api-version 3 role list") do |r|
+        shell("openstack #{auth_creds} --os-auth-url http://127.0.0.1:5000/v3 --os-identity-api-version 3 role assignment list --names") do |r|
           expect(r.stdout).to match(/admin/)
           expect(r.stderr).to be_empty
         end
