@@ -10,9 +10,9 @@ describe 'keystone::endpoint' do
   describe 'with default parameters' do
     it { is_expected.to contain_keystone_endpoint('RegionOne/keystone::identity').with(
       :ensure       => 'present',
-      :public_url   => 'http://127.0.0.1:5000/v2.0',
-      :admin_url    => 'http://127.0.0.1:35357/v2.0',
-      :internal_url => 'http://127.0.0.1:5000/v2.0',
+      :public_url   => 'http://127.0.0.1:5000',
+      :admin_url    => 'http://127.0.0.1:5000',
+      :internal_url => 'http://127.0.0.1:5000',
       :region       => 'RegionOne'
     )}
   end
@@ -37,18 +37,16 @@ describe 'keystone::endpoint' do
     )}
   end
 
-  describe 'without a version' do
-    # We need to test empty value '' to override the default value, using undef
-    # cannot un-set classes parameters.
+  describe 'with unset version to test backward compatibility' do
     let :params do
-      { :version => '' }
+      { :version => 'unset' }
     end
 
     it { is_expected.to contain_keystone_endpoint('RegionOne/keystone::identity').with(
       :ensure       => 'present',
-      :public_url   => 'http://127.0.0.1:5000',
-      :admin_url    => 'http://127.0.0.1:35357',
-      :internal_url => 'http://127.0.0.1:5000'
+      :public_url   => 'http://127.0.0.1:5000/v2.0',
+      :admin_url    => 'http://127.0.0.1:5000/v2.0',
+      :internal_url => 'http://127.0.0.1:5000/v2.0'
     )}
   end
 
@@ -61,8 +59,8 @@ describe 'keystone::endpoint' do
     it 'internal_url should default to public_url' do
       is_expected.to contain_keystone_endpoint('RegionOne/keystone::identity').with(
         :ensure       => 'present',
-        :public_url   => 'https://identity.some.tld/the/main/endpoint/v2.0',
-        :internal_url => 'https://identity.some.tld/the/main/endpoint/v2.0'
+        :public_url   => 'https://identity.some.tld/the/main/endpoint',
+        :internal_url => 'https://identity.some.tld/the/main/endpoint'
       )
     end
   end
