@@ -24,9 +24,7 @@ describe 'keystone' do
       'package_ensure'                     => 'present',
       'client_package_ensure'              => 'present',
       'public_bind_host'                   => '0.0.0.0',
-      'admin_bind_host'                    => '0.0.0.0',
       'public_port'                        => '5000',
-      'admin_port'                         => '35357',
       'catalog_type'                       => 'sql',
       'catalog_driver'                     => false,
       'token_provider'                     => 'fernet',
@@ -46,15 +44,12 @@ describe 'keystone' do
       'ssl_cert_subject'                   => '/C=US/ST=Unset/L=Unset/O=Unset/CN=localhost',
       'enabled'                            => true,
       'manage_service'                     => true,
-      'database_connection'                => 'sqlite:////var/lib/keystone/keystone.db',
-      'database_idle_timeout'              => '200',
       'default_transport_url'              => '<SERVICE DEFAULT>',
       'notification_transport_url'         => '<SERVICE DEFAULT>',
       'rabbit_heartbeat_timeout_threshold' => '<SERVICE DEFAULT>',
       'rabbit_heartbeat_rate'              => '<SERVICE DEFAULT>',
+      'rabbit_heartbeat_in_pthread'        => '<SERVICE DEFAULT>',
       'amqp_durable_queues'                => '<SERVICE DEFAULT>',
-      'admin_workers'                      => 20,
-      'public_workers'                     => 20,
       'member_role_id'                     => '<SERVICE DEFAULT>',
       'member_role_name'                   => '<SERVICE DEFAULT>',
       'sync_db'                            => true,
@@ -67,9 +62,7 @@ describe 'keystone' do
       'package_ensure'                     => 'latest',
       'client_package_ensure'              => 'latest',
       'public_bind_host'                   => '0.0.0.0',
-      'admin_bind_host'                    => '0.0.0.0',
       'public_port'                        => '5001',
-      'admin_port'                         => '35358',
       'admin_token'                        => 'service_token_override',
       'admin_password'                     => 'admin_openstack_password',
       'catalog_type'                       => 'template',
@@ -78,8 +71,7 @@ describe 'keystone' do
       'password_hash_rounds'               => '29000',
       'revoke_driver'                      => 'kvs',
       'revoke_by_id'                       => false,
-      'public_endpoint'                    => 'https://localhost:5000/v2.0/',
-      'admin_endpoint'                     => 'https://localhost:5000/v2.0/',
+      'public_endpoint'                    => 'https://localhost:5000',
       'enable_ssl'                         => true,
       'ssl_certfile'                       => '/etc/keystone/ssl/certs/keystone.pem',
       'ssl_keyfile'                        => '/etc/keystone/ssl/private/keystonekey.pem',
@@ -88,12 +80,11 @@ describe 'keystone' do
       'ssl_cert_subject'                   => '/C=US/ST=Unset/L=Unset/O=Unset/CN=localhost',
       'enabled'                            => false,
       'manage_service'                     => true,
-      'database_connection'                => 'mysql://a:b@c/d',
-      'database_idle_timeout'              => '300',
       'default_transport_url'              => 'rabbit://user:pass@host:1234/virt',
       'notification_transport_url'         => 'rabbit://user:pass@host:1234/virt',
       'rabbit_heartbeat_timeout_threshold' => '60',
       'rabbit_heartbeat_rate'              => '10',
+      'rabbit_heartbeat_in_pthread'        => true,
       'rabbit_ha_queues'                   => true,
       'amqp_durable_queues'                => true,
       'default_domain'                     => 'other_domain',
@@ -153,10 +144,6 @@ describe 'keystone' do
 
     it 'should contain correct config' do
       [
-       'public_bind_host',
-       'admin_bind_host',
-       'public_port',
-       'admin_port',
        'member_role_id',
        'member_role_name',
       ].each do |config|
@@ -169,8 +156,7 @@ describe 'keystone' do
     end
 
     it 'should contain correct mysql config' do
-      is_expected.to contain_keystone_config('database/idle_timeout').with_value(param_hash['database_idle_timeout'])
-      is_expected.to contain_keystone_config('database/connection').with_value(param_hash['database_connection']).with_secret(true)
+      is_expected.to contain_class('keystone::db')
     end
 
     it { is_expected.to contain_keystone_config('token/provider').with_value(
@@ -193,16 +179,11 @@ describe 'keystone' do
       is_expected.to contain_keystone_config('token/revoke_by_id').with_value(param_hash['revoke_by_id'])
     end
 
-    it 'should ensure proper setting of admin_endpoint and public_endpoint' do
-      if param_hash['admin_endpoint']
-        is_expected.to contain_keystone_config('DEFAULT/admin_endpoint').with_value(param_hash['admin_endpoint'])
-      else
-        is_expected.to contain_keystone_config('DEFAULT/admin_endpoint').with_value('<SERVICE DEFAULT>')
-      end
+    it 'should ensure proper setting of public_endpoint' do
       if param_hash['public_endpoint']
         is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value(param_hash['public_endpoint'])
       else
-        is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value('http://127.0.0.1:5000')
       end
     end
 
@@ -213,6 +194,7 @@ describe 'keystone' do
     it 'should contain correct rabbit heartbeat configuration' do
       is_expected.to contain_keystone_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value(param_hash['rabbit_heartbeat_timeout_threshold'])
       is_expected.to contain_keystone_config('oslo_messaging_rabbit/heartbeat_rate').with_value(param_hash['rabbit_heartbeat_rate'])
+      is_expected.to contain_keystone_config('oslo_messaging_rabbit/heartbeat_in_pthread').with_value(param_hash['rabbit_heartbeat_in_pthread'])
       is_expected.to contain_keystone_config('oslo_messaging_rabbit/amqp_durable_queues').with_value(param_hash['amqp_durable_queues'])
     end
 
@@ -220,19 +202,6 @@ describe 'keystone' do
       is_expected.to contain_keystone_config('DEFAULT/max_token_size').with_value('<SERVICE DEFAULT>')
     end
 
-    it 'should ensure proper setting of admin_workers and public_workers' do
-      if param_hash['admin_workers']
-        is_expected.to contain_keystone_config('eventlet_server/admin_workers').with_value(param_hash['admin_workers'])
-      else
-        is_expected.to contain_keystone_config('eventlet_server/admin_workers').with_value('2')
-      end
-      if param_hash['public_workers']
-        is_expected.to contain_keystone_config('eventlet_server/public_workers').with_value(param_hash['public_workers'])
-      else
-        is_expected.to contain_keystone_config('eventlet_server/public_workers').with_value('2')
-      end
-    end
-
     it 'should ensure rabbit_ha_queues' do
       if param_hash['rabbit_ha_queues']
         is_expected.to contain_keystone_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value(param_hash['rabbit_ha_queues'])
@@ -315,6 +284,49 @@ describe 'keystone' do
     ) }
   end
 
+  describe 'when public_bind_host or public_bind_port are set' do
+    describe 'when ipv6 loopback is set' do
+      let :params do
+        {
+          :admin_token      => 'service_token',
+          :public_bind_host => '::0'
+        }
+      end
+      it { is_expected.to contain_keystone_config("DEFAULT/public_endpoint").with_value('http://[::1]:5000') }
+    end
+
+    describe 'when ipv4 address is set' do
+      let :params do
+        {
+          :admin_token      => 'service_token',
+          :public_bind_host => '192.168.0.1',
+          :public_port      => '15000'
+        }
+      end
+      it { is_expected.to contain_keystone_config("DEFAULT/public_endpoint").with_value('http://192.168.0.1:15000') }
+    end
+
+    describe 'when unenclosed ipv6 address is set' do
+      let :params do
+        {
+          :admin_token      => 'service_token',
+          :public_bind_host => '2001:db8::1'
+        }
+      end
+      it { is_expected.to contain_keystone_config("DEFAULT/public_endpoint").with_value('http://[2001:db8::1]:5000') }
+    end
+
+    describe 'when enclosed ipv6 address is set' do
+      let :params do
+        {
+          :admin_token      => 'service_token',
+          :public_bind_host => '[2001:db8::1]'
+        }
+      end
+      it { is_expected.to contain_keystone_config("DEFAULT/public_endpoint").with_value('http://[2001:db8::1]:5000') }
+    end
+  end
+
   describe 'when using invalid service name for keystone' do
     let (:params) { {'service_name' => 'foo'}.merge(default_params) }
 
@@ -416,9 +428,9 @@ describe 'keystone' do
         'admin_token'                  => 'service_token',
         'cache_backend'                => 'dogpile.cache.memcached',
         'cache_backend_argument'       => ['url:SERVER1:12211'],
-        'cache_memcache_servers'       => 'SERVER1:11211,SERVER2:11211',
+        'cache_memcache_servers'       => 'SERVER1:11211,SERVER2:11211,[fd12:3456:789a:1::1]:11211',
         'memcache_dead_retry'          => '60',
-        'memcache_socket_timeout'      => '2',
+        'memcache_socket_timeout'      => '2.0',
         'memcache_pool_maxsize'        => '1000',
         'memcache_pool_unused_timeout' => '60',
       }
@@ -429,14 +441,14 @@ describe 'keystone' do
     it { is_expected.to contain_keystone_config('cache/backend').with_value('dogpile.cache.memcached') }
     it { is_expected.to contain_keystone_config('cache/backend_argument').with_value('url:SERVER1:12211') }
     it { is_expected.to contain_keystone_config('memcache/dead_retry').with_value('60') }
-    it { is_expected.to contain_keystone_config('memcache/socket_timeout').with_value('2') }
+    it { is_expected.to contain_keystone_config('memcache/socket_timeout').with_value('2.0') }
     it { is_expected.to contain_keystone_config('memcache/pool_maxsize').with_value('1000') }
     it { is_expected.to contain_keystone_config('memcache/pool_unused_timeout').with_value('60') }
     it { is_expected.to contain_keystone_config('cache/memcache_dead_retry').with_value('60') }
-    it { is_expected.to contain_keystone_config('cache/memcache_socket_timeout').with_value('2') }
+    it { is_expected.to contain_keystone_config('cache/memcache_socket_timeout').with_value('2.0') }
     it { is_expected.to contain_keystone_config('cache/memcache_pool_maxsize').with_value('1000') }
     it { is_expected.to contain_keystone_config('cache/memcache_pool_unused_timeout').with_value('60') }
-    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER1:11211,SERVER2:11211') }
+    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER1:11211,SERVER2:11211,inet6:[fd12:3456:789a:1::1]:11211') }
   end
 
   describe 'configure cache memcache servers if set' do
@@ -445,9 +457,9 @@ describe 'keystone' do
         'admin_token'                          => 'service_token',
         'cache_backend'                        => 'dogpile.cache.memcached',
         'cache_backend_argument'               => ['url:SERVER3:12211'],
-        'cache_memcache_servers'               => [ 'SERVER1:11211', 'SERVER2:11211' ],
+        'cache_memcache_servers'               => [ 'SERVER1:11211', 'SERVER2:11211', '[fd12:3456:789a:1::1]:11211' ],
         'memcache_dead_retry'                  => '60',
-        'memcache_socket_timeout'              => '2',
+        'memcache_socket_timeout'              => '2.0',
         'memcache_pool_maxsize'                => '1000',
         'memcache_pool_unused_timeout'         => '60',
         'memcache_pool_connection_get_timeout' => '30',
@@ -460,15 +472,15 @@ describe 'keystone' do
     it { is_expected.to contain_keystone_config('cache/backend').with_value('dogpile.cache.memcached') }
     it { is_expected.to contain_keystone_config('cache/backend_argument').with_value('url:SERVER3:12211') }
     it { is_expected.to contain_keystone_config('memcache/dead_retry').with_value('60') }
-    it { is_expected.to contain_keystone_config('memcache/socket_timeout').with_value('2') }
+    it { is_expected.to contain_keystone_config('memcache/socket_timeout').with_value('2.0') }
     it { is_expected.to contain_keystone_config('memcache/pool_maxsize').with_value('1000') }
     it { is_expected.to contain_keystone_config('memcache/pool_unused_timeout').with_value('60') }
     it { is_expected.to contain_keystone_config('cache/memcache_dead_retry').with_value('60') }
-    it { is_expected.to contain_keystone_config('cache/memcache_socket_timeout').with_value('2') }
+    it { is_expected.to contain_keystone_config('cache/memcache_socket_timeout').with_value('2.0') }
     it { is_expected.to contain_keystone_config('cache/memcache_pool_maxsize').with_value('1000') }
     it { is_expected.to contain_keystone_config('cache/memcache_pool_unused_timeout').with_value('60') }
     it { is_expected.to contain_keystone_config('cache/memcache_pool_connection_get_timeout').with_value('30') }
-    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER1:11211,SERVER2:11211') }
+    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER1:11211,SERVER2:11211,inet6:[fd12:3456:789a:1::1]:11211') }
     it { is_expected.to contain_oslo__cache('keystone_config').with_manage_backend_package(false) }
   end
 
@@ -479,9 +491,9 @@ describe 'keystone' do
         'cache_backend'                        => 'dogpile.cache.memcached',
         'cache_backend_argument'               => ['url:SERVER3:12211'],
         'cache_enabled'                        => true,
-        'cache_memcache_servers'               => [ 'SERVER1:11211', 'SERVER2:11211' ],
+        'cache_memcache_servers'               => [ 'SERVER1:11211', 'SERVER2:11211', '[fd12:3456:789a:1::1]:11211' ],
         'memcache_dead_retry'                  => '60',
-        'memcache_socket_timeout'              => '2',
+        'memcache_socket_timeout'              => '2.0',
         'memcache_pool_maxsize'                => '1000',
         'memcache_pool_unused_timeout'         => '60',
         'memcache_pool_connection_get_timeout' => '30',
@@ -493,25 +505,25 @@ describe 'keystone' do
     it { is_expected.to contain_keystone_config('cache/backend').with_value('dogpile.cache.memcached') }
     it { is_expected.to contain_keystone_config('cache/backend_argument').with_value('url:SERVER3:12211') }
     it { is_expected.to contain_keystone_config('memcache/dead_retry').with_value('60') }
-    it { is_expected.to contain_keystone_config('memcache/socket_timeout').with_value('2') }
+    it { is_expected.to contain_keystone_config('memcache/socket_timeout').with_value('2.0') }
     it { is_expected.to contain_keystone_config('memcache/pool_maxsize').with_value('1000') }
     it { is_expected.to contain_keystone_config('memcache/pool_unused_timeout').with_value('60') }
     it { is_expected.to contain_keystone_config('cache/memcache_dead_retry').with_value('60') }
-    it { is_expected.to contain_keystone_config('cache/memcache_socket_timeout').with_value('2') }
+    it { is_expected.to contain_keystone_config('cache/memcache_socket_timeout').with_value('2.0') }
     it { is_expected.to contain_keystone_config('cache/memcache_pool_maxsize').with_value('1000') }
     it { is_expected.to contain_keystone_config('cache/memcache_pool_unused_timeout').with_value('60') }
     it { is_expected.to contain_keystone_config('cache/memcache_pool_connection_get_timeout').with_value('30') }
-    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER1:11211,SERVER2:11211') }
+    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER1:11211,SERVER2:11211,inet6:[fd12:3456:789a:1::1]:11211') }
   end
 
   describe 'configure memcache servers with a string' do
     let :params do
       default_params.merge({
-        'cache_memcache_servers' => 'SERVER1:11211,SERVER2:11211'
+        'cache_memcache_servers' => 'SERVER1:11211,SERVER2:11211,[fd12:3456:789a:1::1]:11211'
       })
     end
 
-    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER1:11211,SERVER2:11211') }
+    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER1:11211,SERVER2:11211,inet6:[fd12:3456:789a:1::1]:11211') }
   end
 
   describe 'do not configure memcache servers when not set' do
@@ -540,8 +552,7 @@ describe 'keystone' do
       {
         'admin_token'     => 'service_token',
         'enable_ssl'      => true,
-        'public_endpoint' => 'https://localhost:5000/v2.0/',
-        'admin_endpoint'  => 'https://localhost:5000/v2.0/',
+        'public_endpoint' => 'https://localhost:5000',
       }
     end
     it {is_expected.to contain_keystone_config('ssl/enable').with_value(true)}
@@ -550,9 +561,9 @@ describe 'keystone' do
     it {is_expected.to contain_keystone_config('ssl/ca_certs').with_value('/etc/keystone/ssl/certs/ca.pem')}
     it {is_expected.to contain_keystone_config('ssl/ca_key').with_value('/etc/keystone/ssl/private/cakey.pem')}
     it {is_expected.to contain_keystone_config('ssl/cert_subject').with_value('/C=US/ST=Unset/L=Unset/O=Unset/CN=localhost')}
-    it {is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value('https://localhost:5000/v2.0/')}
-    it {is_expected.to contain_keystone_config('DEFAULT/admin_endpoint').with_value('https://localhost:5000/v2.0/')}
+    it {is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value('https://localhost:5000')}
   end
+
   describe 'when disabling SSL' do
     let :params do
       {
@@ -561,9 +572,9 @@ describe 'keystone' do
       }
     end
     it {is_expected.to contain_keystone_config('ssl/enable').with_value(false)}
-    it {is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value('<SERVICE DEFAULT>')}
-    it {is_expected.to contain_keystone_config('DEFAULT/admin_endpoint').with_value('<SERVICE DEFAULT>')}
+    it {is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value('http://127.0.0.1:5000')}
   end
+
   describe 'not setting notification settings by default' do
     let :params do
       default_params
@@ -666,6 +677,16 @@ describe 'keystone' do
     )}
   end
 
+  describe 'setting max_request_body_size' do
+    let :params do
+      default_params.merge({:max_request_body_size => '1146880' })
+    end
+
+    it { is_expected.to contain_oslo__middleware('keystone_config').with(
+      :max_request_body_size => '1146880',
+    )}
+  end
+
   describe 'setting sql policy driver' do
     let :params do
       default_params.merge({:policy_driver => 'sql' })
@@ -699,15 +720,14 @@ describe 'keystone' do
       {
         :admin_token       => 'service_token',
         :validate_service  => true,
-        :validate_auth_url => 'http://some.host:5000/v2.0',
+        :validate_auth_url => 'http://some.host:5000',
         :admin_endpoint    => 'http://some.host:5000'
       }
     end
 
-    it { is_expected.to contain_keystone_config('DEFAULT/admin_endpoint').with_value('http://some.host:5000') }
     it { is_expected.to contain_class('keystone::service').with(
       'validate'       => true,
-      'admin_endpoint' => 'http://some.host:5000/v2.0'
+      'admin_endpoint' => 'http://some.host:5000'
     )}
   end
 
@@ -811,13 +831,11 @@ describe 'keystone' do
       it { is_expected.to contain_file('/etc/keystone/credential-keys/0').with(
         'content'   => 't-WdduhORSqoyAykuqWAQSYjg2rSRuJYySgI2xh48CI=',
         'owner'     => 'keystone',
-        'owner'     => 'keystone',
         'subscribe' => 'Anchor[keystone::install::end]',
       )}
       it { is_expected.to contain_file('/etc/keystone/credential-keys/1').with(
         'content'   => 'GLlnyygEVJP4-H2OMwClXn3sdSQUZsM5F194139Unv8=',
         'owner'     => 'keystone',
-        'owner'     => 'keystone',
         'subscribe' => 'Anchor[keystone::install::end]',
       )}
     end
