@@ -3,7 +3,10 @@ require 'spec_helper'
 describe 'keystone::service' do
 
   let :facts do
-    @default_facts.merge({ :osfamily => 'Debian' })
+    @default_facts.merge({
+       :osfamily => 'Debian',
+       :os       => { :name  => 'Debian', :family => 'Debian', :release => { :major => '8', :minor => '0' } },
+    })
   end
 
   describe "with default parameters" do
