@@ -24,7 +24,7 @@ at_exit { RSpec::Puppet::Coverage.report! }
 def setup_provider_tests
   Puppet::Provider::Keystone.class_exec do
     def self.reset
-      @admin_endpoint = nil
+      @public_endpoint = nil
       @tenant_hash    = nil
       @admin_token    = nil
       @keystone_file  = nil
